Folders class

The Flutter Hue folder structure.

Constructors

Folders()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

bridgesSubPath → String
The sub path for the bridges.
no setter
remoteTokensSubPath → String
The sub path for the remote tokens.
no setter

Constants

bridges → const String
The folder for the bridges.
remoteTokens → const String
The folder for the remote tokens.
top → const String
The top level folder.