DiscoveredBridge class

A class that represents a bridge that has been discovered but not yet connected to the app.

Constructors

DiscoveredBridge({String? rawIdFromEndpoint, String? rawIdFromMdns, required String ipAddress})
Creates a new DiscoveredBridge instance.
DiscoveredBridge.empty()
Creates an empty DiscoveredBridge instance.
DiscoveredBridge.fromEndpoint({required String? rawIdFromEndpoint, required String ipAddress})
Creates a new DiscoveredBridge instance when using the endpoint bridge discovery method.
DiscoveredBridge.fromMdns({required String? rawIdFromMdns, required String ipAddress})
Creates a new DiscoveredBridge instance when using the mDNS bridge discovery method.

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → String?
This is a partial ID of the bridge.
no setter
ipAddress → String
The IP address of the bridge.
final
isEmpty → bool
Whether or not this user object is empty.
no setter
isNotEmpty → bool
Whether or not this user object is not empty.
no setter
rawIdFromEndpoint ↔ String?
This should be the full ID of the bridge.
getter/setter pair
rawIdFromMdns ↔ String?
This is still a partial ID for the bridge; however, id does contain more data than id.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copy() → DiscoveredBridge
Returns a copy of this object.
copyWith({Object? rawIdFromEndpoint = sentinelValue, Object? rawIdFromMdns = sentinelValue, String? ipAddress}) → DiscoveredBridge
Returns a copy of this object with its field values replaced by the ones provided to this method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

sentinelValue → const Object
Used in the copyWith method to check if nullable values are meant to be copied over.