DeviceProductData class

Represents the product data of a Philips Hue device.

Constructors

DeviceProductData({required String modelId, required String manufacturerName, required String productName, required DeviceArchetype productArchetype, required bool isCertified, required String softwareVersion, required String hardwarePlatformType})
Creates a DeviceProductData object.
DeviceProductData.empty()
Creates an empty DeviceProductData object.
DeviceProductData.fromJson(Map<String, dynamic> dataMap)
Creates a DeviceProductData object from the JSON response to a GET request.
factory

Properties

hardwarePlatformType → String
Hardware type - identified by Manufacturer code and ImageType.
final
hashCode → int
The hash code for this object.
no setteroverride
isCertified → bool
Whether or not this device is Hue certified
final
manufacturerName → String
Name of device manufacturer
final
modelId → String
Unique identification of device model.
final
productArchetype → DeviceArchetype
Archetype of the product.
final
productName → String
Name of the product.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softwareVersion → String
Software version of the product.
final

Methods

copyWith({String? modelId, String? manufacturerName, String? productName, DeviceArchetype? productArchetype, bool? isCertified, String? softwareVersion, String? hardwarePlatformType}) → DeviceProductData
Returns a copy of this object with its field values replaced by the ones provided to this method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts this object into JSON format.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override