DevicePower class

Represents a Philips Hue device's power level.

Inheritance

Constructors

DevicePower({required ResourceType type, required String id, String idV1 = '', required Relative owner, required DevicePowerPowerState powerState})
Creates a DevicePower object.
DevicePower.empty()
Creates an empty DevicePower object.
DevicePower.fromJson(Map<String, dynamic> dataMap)
Creates a DevicePower object from the JSON response to a GET request.
factory

Properties

bridge ↔ Bridge?
The bridge that this resource is associated with.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setterinherited
hueNetwork ↔ HueNetwork?
The HueNetwork that this resource is associated with.
getter/setter pairinherited
id → String
Unique identifier representing a specific resource instance.
finalinherited
idV1 → String
Clip v1 resource identifier.
final
originalType → ResourceType
no setterinherited
owner → Relative
Owner of the service, in case the owner service is deleted, the service also gets deleted
final
ownerAsResource → Resource
Returns a Resource object that represents the owner of this Resource.
no setter
powerState → DevicePowerPowerState
The power state of this device.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ResourceType
Type of the supported resource.
getter/setter pairinherited

Methods

copyWith({ResourceType? type, String? id, String? idV1, Relative? owner, DevicePowerPowerState? powerState, bool copyOriginalValues = true}) → DevicePower
Returns a copy of this object with its field values replaced by the ones provided to this method.
getRelativeAsResource(Relative relative) → Resource
Returns a Resource object that represents the relative of this Resource.
inherited
getRelativesAsResources(List<Relative> relatives) → List<Resource>
Returns a list of Resource objects that represent the relatives of this Resource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
inherited
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override