HueNetwork class

Constructors

HueNetwork({required List<Bridge> bridges})

Properties

behaviorInstances → List<BehaviorInstance>
All of the BehaviorInstance objects on the network that the user's device has permission to access.
no setter
behaviorScripts → List<BehaviorScript>
All of the BehaviorScript objects on the network that the user's device has permission to access.
no setter
bridgeHomes → List<BridgeHome>
All of the BridgeHome objects on the network that the user's device has permission to access.
no setter
bridges ↔ List<Bridge>
All of the bridges the user's device has access to on the network.
getter/setter pair
buttons → List<Button>
All of the Button objects on the network that the user's device has permission to access.
no setter
devicePowers → List<DevicePower>
All of the DevicePower objects on the network that the user's device has permission to access.
no setter
devices → List<Device>
All of the Device objects on the network that the user's device has permission to access.
no setter
entertainmentConfigurations → List<EntertainmentConfiguration>
All of the EntertainmentConfiguration objects on the network that the user's device has permission to access.
no setter
entertainments → List<Entertainment>
All of the Entertainment objects on the network that the user's device has permission to access.
no setter
failedFetches → List<FailedResource>
All of the resources that failed to be fetched.
no setter
geofenceClients → List<GeofenceClient>
All of the GeofenceClient objects on the network that the user's device has permission to access.
no setter
geolocations → List<Geolocation>
All of the Geolocation objects on the network that the user's device has permission to access.
no setter
groupedLights → List<GroupedLight>
All of the GroupedLight objects on the network that the user's device has permission to access.
no setter
hasFailedFetches → bool
Whether or not there are any failed fetches.
no setter
hashCode → int
The hash code for this object.
no setterinherited
homekits → List<Homekit>
All of the Homekit objects on the network that the user's device has permission to access.
no setter
lightLevels → List<LightLevel>
All of the LightLevel objects on the network that the user's device has permission to access.
no setter
lights → List<Light>
All of the Light objects on the network that the user's device has permission to access.
no setter
matterFabrics → List<MatterFabric>
All of the MatterFabric objects on the network that the user's device has permission to access.
no setter
matters → List<Matter>
All of the Matter objects on the network that the user's device has permission to access.
no setter
motions → List<Motion>
All of the Motion objects on the network that the user's device has permission to access.
no setter
relativeRotaries → List<RelativeRotary>
All of the RelativeRotary objects on the network that the user's device has permission to access.
no setter
resources → List<List<Resource>>
A single list that contains all of the resource lists.
no setter
rooms → List<Room>
All of the Room objects on the network that the user's device has permission to access.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scenes → List<Scene>
All of the Scene objects on the network that the user's device has permission to access.
no setter
smartScenes → List<SmartScene>
All of the SmartScene objects on the network that the user's device has permission to access.
no setter
temperatures → List<Temperature>
All of the Temperature objects on the network that the user's device has permission to access.
no setter
zgpConnectivities → List<ZgpConnectivity>
All of the ZgpConnectivity objects on the network that the user's device has permission to access.
no setter
zigbeeConnectivities → List<ZigbeeConnectivity>
All of the ZigbeeConnectivity objects on the network that the user's device has permission to access.
no setter
zigbeeDeviceDiscoveries → List<ZigbeeDeviceDiscovery>
All of the ZigbeeDeviceDiscovery objects on the network that the user's device has permission to access.
no setter
zones → List<Zone>
All of the Zone objects on the network that the user's device has permission to access.
no setter

Methods

addBridge(Bridge bridge) → bool
Adds a bridge to the bridges list.
addPoint(Bridge bridge) → bool
Adds a bridge to the bridges list.
clearFailedFetches() → void
Removes all of the failed fetches.
fetch({required String resourceId, required ResourceType type, Bridge? bridge, String decrypter(String ciphertext)?}) → Future<void>
Fetches the resource with the given resourceId and type from the network.
fetchAll({List<Bridge>? bridges, String decrypter(String ciphertext)?}) → Future<void>
Fetch all of the Philip's Hue devices on the network that this device has permission to fetch.
fetchAllFailed({String decrypter(String ciphertext)?}) → Future<void>
Fetch all of the Philip's Hue devices on the network that this device has permission to fetch which failed to be fetched in the last fetch.
fetchAllFailedType(ResourceType type, {String decrypter(String ciphertext)?}) → Future<void>
Fetch all of the Philip's Hue devices of the given type on the network that this device has permission to fetch which failed to be fetched in the last fetch.
fetchAllType(ResourceType type, {List<Bridge>? bridges, String decrypter(String ciphertext)?}) → Future<void>
Fetch all of the Philip's Hue devices of the given type on the network that this device has permission to fetch.
getListType(ResourceType type) → List<Resource>?
Returns the resource list that goes with the given type.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
put({String decrypter(String ciphertext)?}) → Future<void>
Sends a PUT request to the bridge for each resource in the list.
removeBridge(Bridge bridge) → bool
Removes a bridge from the bridges list.
removePoint(Bridge bridge) → bool
Removes a bridge from the bridges list.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited