LightAlert class

Represents a light alert.

Constructors

LightAlert({required List<String> actionValues, String? action})
Creates a LightAlert object.
LightAlert.empty()
Creates an empty LightAlert object.
LightAlert.fromJson(Map<String, dynamic> dataMap)
Creates a LightAlert object from the JSON response to a GET request.
factory

Properties

action ↔ String?
Alert effect for the light.
getter/setter pair
actionValues → List<String>
Alert effects that the light supports.
final
hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<String>? actionValues, String? action = '', bool copyOriginalValues = true}) → LightAlert
Returns a copy of this object with its field values replaced by the ones provided to this method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override