LightGradientFull class

Represents the current gradient and gradient capabilities of a light.

Inheritance

Constructors

LightGradientFull({required List<LightColorXy> points, required String mode, required List<String> modeValues, required int pointsCapable, required int pixelCount})
Creates a LightGradientFull object.
LightGradientFull.empty()
Creates an empty LightGradientFull object.
LightGradientFull.fromJson(Map<String, dynamic> dataMap)
Creates a LightGradientFull object from the JSON response to a GET request.
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setterinherited
mode ↔ String
Mode in which the points are currently being deployed.
getter/setter pairinherited
modeValues → List<String>
Modes a gradient device can deploy the gradient palette of colors.
finalinherited
originalMode → String
The value of mode when this object was instantiated.
no setterinherited
originalPoints → List<LightColorXy>
The value of points when this object was instantiated.
no setterinherited
pixelCount → int
Number of pixels in the device.
final
points ↔ List<LightColorXy>
Collection of gradients points.
getter/setter pairinherited
pointsCapable → int
Number of color points that gradient lamp is capable of showing with gradients.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addPoint(LightColorXy point) → bool
Adds a point to the points array.
inherited
copyWith({List<LightColorXy>? points, String? mode, List<String>? modeValues, int? pointsCapable, int? pixelCount, bool copyOriginalValues = true}) → LightGradientFull
Returns a copy of this object with its field values replaced by the ones provided to this method.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
inherited
removePoint(LightColorXy point) → bool
Removes a point from the points array.
inherited
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override