LightMetadata class

Represents a light's metadata.

Constructors

LightMetadata({required String name, required LightArchetype archetype, required int fixedMired})
Creates a LightMetadata object.
LightMetadata.empty()
Creates an empty LightMetadata object.
LightMetadata.fromJson(Map<String, dynamic> dataMap)
Creates a LightMetadata object from the JSON response to a GET request.
factory

Properties

archetype ↔ LightArchetype
Light archetype.
getter/setter pair
fixedMired → int
A fixed mired value of the white lamp.
final
hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setter
name ↔ String
Human readable name of a resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? name, LightArchetype? archetype, int? fixedMired, bool copyOriginalValues = true}) → LightMetadata
Returns a copy of this object with its field values replaced by the ones provided to this method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override