Matter class

The configuration settings for a matter resource.

Inheritance

Constructors

Matter({required ResourceType type, required String id, String idV1 = '', required int maxFabrics, required bool hasQrCode, String? action})
Creates a Matter object.
Matter.empty()
Creates an empty Matter object.
Matter.fromJson(Map<String, dynamic> dataMap)
Creates a Matter object from the JSON response to a GET request.
factory

Properties

action ↔ String?
matter_reset: Resets Matter, including removing all fabrics and reset state to factory settings.
getter/setter pair
bridge ↔ Bridge?
The bridge that this resource is associated with.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setteroverride
hasQrCode → bool
Whether or not a physical QR code is present.
final
hasUpdate → bool
Whether or not this object has been updated.
no setteroverride
hueNetwork ↔ HueNetwork?
The HueNetwork that this resource is associated with.
getter/setter pairinherited
id → String
Unique identifier representing a specific resource instance.
finalinherited
idV1 → String
Clip v1 resource identifier.
final
maxFabrics → int
Maximum number of fabrics that can exist at a time.
final
originalType → ResourceType
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ResourceType
Type of the supported resource.
getter/setter pairinherited

Methods

copyWith({ResourceType? type, String? id, String? idV1, int? maxFabrics, bool? hasQrCode, String? action = '', bool copyOriginalValues = true}) → Matter
Returns a copy of this object with its field values replaced by the ones provided to this method.
getRelativeAsResource(Relative relative) → Resource
Returns a Resource object that represents the relative of this Resource.
inherited
getRelativesAsResources(List<Relative> relatives) → List<Resource>
Returns a list of Resource objects that represent the relatives of this Resource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
override
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override