Relative class

Represents a relative to a resource.

Inheritance

Constructors

Relative({required ResourceType type, required String id})
Creates a Relative object.
Relative.empty()
Creates an empty Relative object.
Relative.fromJson(Map<String, dynamic> dataMap)
Creates a Relative object from the JSON response to a GET request.
factory

Properties

bridge ↔ Bridge?
The bridge that this resource is associated with.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setterinherited
hueNetwork ↔ HueNetwork?
The HueNetwork that this resource is associated with.
getter/setter pairinherited
id → String
Unique identifier representing a specific resource instance.
finalinherited
originalType → ResourceType
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ ResourceType
Type of the supported resource.
getter/setter pairinherited

Methods

copyWith({ResourceType? type, String? id, bool copyOriginalValues = true}) → Relative
Returns a copy of this object with its field values replaced by the ones provided to this method.
getRelativeAsResource(Relative relative) → Resource
Returns a Resource object that represents the relative of this Resource.
inherited
getRelativesAsResources(List<Relative> relatives) → List<Resource>
Returns a list of Resource objects that represent the relatives of this Resource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
inherited
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override