Scene class

Represents a Philips Hue scene.

Inheritance

Constructors

Scene({required ResourceType type, required String id, String idV1 = '', required List<SceneAction> actions, required SceneRecall recall, required SceneMetadata metadata, required Relative group, required ScenePalette palette, required double speed, required bool autoDynamic})
Creates a Scene object.
Scene.empty()
Creates an empty Scene object.
Scene.fromJson(Map<String, dynamic> dataMap)
Creates a Scene object from the JSON response to a GET request.
factory

Properties

actions ↔ List<SceneAction>
List of actions to be executed synchronously on recall.
getter/setter pair
autoDynamic ↔ bool
Whether or not to automatically start the scene dynamically on active recall.
getter/setter pair
bridge ↔ Bridge?
The bridge that this resource is associated with.
getter/setter pairinherited
group → Relative
Group associated with this Scene.
final
groupAsResource → Resource
Returns a Resource object that represents the group of this Resource.
no setter
hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setteroverride
hueNetwork ↔ HueNetwork?
The HueNetwork that this resource is associated with.
getter/setter pairinherited
id → String
Unique identifier representing a specific resource instance.
finalinherited
idV1 → String
Clip v1 resource identifier.
final
imageAsResource → Resource
Returns a Resource object that represents the metadata.image of this Resource.
no setter
metadata ↔ SceneMetadata
Metadata about this scene.
getter/setter pair
originalType → ResourceType
no setterinherited
palette ↔ ScenePalette
Group of colors that describe the palette of colors to be used when playing dynamics.
getter/setter pair
recall ↔ SceneRecall
The recall settings for a scene.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed ↔ double
Speed of dynamic palette for this scene.
getter/setter pair
targetsAsResources → List<Resource>
Returns a list of the action targets as Resource objects.
no setter
type ↔ ResourceType
Type of the supported resource.
getter/setter pairinherited

Methods

copyWith({ResourceType? type, String? id, String? idV1, List<SceneAction>? actions, SceneRecall? recall, SceneMetadata? metadata, Relative? group, ScenePalette? palette, double? speed, bool? autoDynamic, bool copyOriginalValues = true}) → Scene
Returns a copy of this object with its field values replaced by the ones provided to this method.
getRelativeAsResource(Relative relative) → Resource
Returns a Resource object that represents the relative of this Resource.
inherited
getRelativesAsResources(List<Relative> relatives) → List<Resource>
Returns a list of Resource objects that represent the relatives of this Resource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
override
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override