SmartScene class

Represents a smart scene resource.

Inheritance

Constructors

SmartScene({required ResourceType type, required String id, String idV1 = '', required SmartSceneMetadata metadata, required Relative group, required List<SmartSceneWeek> weekTimeslots, required SmartSceneActiveTimeslot activeTimeslot, required String state, String? recallAction})
Creates a SmartScene object.
SmartScene.empty()
Creates an empty SmartScene object.
SmartScene.fromJson(Map<String, dynamic> dataMap)
Creates a SmartScene object from the JSON response to a GET request.
factory

Properties

activeTimeslot → SmartSceneActiveTimeslot
The active time slot in execution.
final
bridge ↔ Bridge?
The bridge that this resource is associated with.
getter/setter pairinherited
group → Relative
Group associated with this Scene.
final
hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setteroverride
hueNetwork ↔ HueNetwork?
The HueNetwork that this resource is associated with.
getter/setter pairinherited
id → String
Unique identifier representing a specific resource instance.
finalinherited
idV1 → String
Clip v1 resource identifier.
final
imageAsResource → Resource
Returns a Resource object that represents the metadata.image of this Resource.
no setter
metadata ↔ SmartSceneMetadata
Metadata about this smart scene.
getter/setter pair
originalType → ResourceType
no setterinherited
recallAction ↔ String?
"activate" will start the smart (24h) scene; "deactivate" will stop it.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String
The current state of the smart scene.
final
targetsAsResources → List<Resource>
Returns a list of the targets as Resource objects.
no setter
type ↔ ResourceType
Type of the supported resource.
getter/setter pairinherited
weekTimeslots ↔ List<SmartSceneWeek>
Information on what is the light state for every timeslot of the day.
getter/setter pair

Methods

copyWith({ResourceType? type, String? id, String? idV1, SmartSceneMetadata? metadata, Relative? group, List<SmartSceneWeek>? weekTimeslots, SmartSceneActiveTimeslot? activeTimeslot, String? state, String? recallAction = '', bool copyOriginalValues = true}) → SmartScene
Returns a copy of this object with its field values replaced by the ones provided to this method.
getRelativeAsResource(Relative relative) → Resource
Returns a Resource object that represents the relative of this Resource.
inherited
getRelativesAsResources(List<Relative> relatives) → List<Resource>
Returns a list of Resource objects that represent the relatives of this Resource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
override
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override