Temperature class

Represents Philips Hue temperature sensor.

Inheritance

Constructors

Temperature({required ResourceType type, required String id, String idV1 = '', required Relative owner, required bool isEnabled, required double temperatureCelsius, required bool isValidTemperature})
Creates a Temperature object.
Temperature.empty()
Creates an empty Temperature object.
Temperature.fromJson(Map<String, dynamic> dataMap)
Creates a Temperature object from the JSON response to a GET request.
factory

Properties

bridge ↔ Bridge?
The bridge that this resource is associated with.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setteroverride
hueNetwork ↔ HueNetwork?
The HueNetwork that this resource is associated with.
getter/setter pairinherited
id → String
Unique identifier representing a specific resource instance.
finalinherited
idV1 → String
Clip v1 resource identifier.
final
isEnabled ↔ bool
Whether or not the sensor is activated.
getter/setter pair
isValidTemperature → bool
Whether or not the value presented in temperature is valid.
final
originalType → ResourceType
no setterinherited
owner → Relative
Owner of the service, in case the owner service is deleted, the service also gets deleted
final
ownerAsResource → Resource
Returns a Resource object that represents the owner of this Resource.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temperatureCelsius → double
Temperature in 1.00 degrees Celsius.
final
type ↔ ResourceType
Type of the supported resource.
getter/setter pairinherited

Methods

copyWith({ResourceType? type, String? id, String? idV1, Relative? owner, bool? isEnabled, double? temperatureCelsius, bool? isValidTemperature, bool copyOriginalValues = true}) → Temperature
Returns a copy of this object with its field values replaced by the ones provided to this method.
getRelativeAsResource(Relative relative) → Resource
Returns a Resource object that represents the relative of this Resource.
inherited
getRelativesAsResources(List<Relative> relatives) → List<Resource>
Returns a list of Resource objects that represent the relatives of this Resource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
override
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override