ZigbeeConnectivity class

Represents zigbee connectivity of a device.

Inheritance

Constructors

ZigbeeConnectivity({required ResourceType type, required String id, String idV1 = '', required Relative owner, required String status, required String macAddress})
Creates a ZigbeeConnectivity object.
ZigbeeConnectivity.empty()
Creates an empty ZigbeeConnectivity object.
ZigbeeConnectivity.fromJson(Map<String, dynamic> dataMap)
Creates a ZigbeeConnectivity object from the JSON response to a GET request.
factory

Properties

bridge ↔ Bridge?
The bridge that this resource is associated with.
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setteroverride
hueNetwork ↔ HueNetwork?
The HueNetwork that this resource is associated with.
getter/setter pairinherited
id → String
Unique identifier representing a specific resource instance.
finalinherited
idV1 → String
Clip v1 resource identifier.
final
macAddress → String
The MAC address of this zigbee connected device.
final
originalType → ResourceType
no setterinherited
owner → Relative
Owner of the service, in case the owner service is deleted, the service also gets deleted
final
ownerAsResource → Resource
Returns a Resource object that represents the owner of this Resource.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
Describes this device's connection status to the zigbee network.
final
type ↔ ResourceType
Type of the supported resource.
getter/setter pairinherited

Methods

copyWith({ResourceType? type, String? id, String? idV1, Relative? owner, String? status, String? macAddress, bool copyOriginalValues = true}) → ZigbeeConnectivity
Returns a copy of this object with its field values replaced by the ones provided to this method.
getRelativeAsResource(Relative relative) → Resource
Returns a Resource object that represents the relative of this Resource.
inherited
getRelativesAsResources(List<Relative> relatives) → List<Resource>
Returns a list of Resource objects that represent the relatives of this Resource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
inherited
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override