Zone class

Represents a zone in the Philips Hue data structure.

Inheritance

Constructors

Zone({required ResourceType type, required String id, String idV1 = '', required List<Relative> children, required List<Relative> services, required RoomMetadata metadata})
Creates a Zone object.
Zone.empty()
Creates an empty Zone object.
Zone.fromJson(Map<String, dynamic> dataMap)
Creates a Zone object from the JSON response to a GET request.
factory

Properties

bridge ↔ Bridge?
The bridge that this resource is associated with.
getter/setter pairinherited
children ↔ List<Relative>
Child devices/services to group by the derived group.
getter/setter pair
childrenAsResources → List<Resource>
Returns a list of the children as Resource objects.
no setter
hashCode → int
The hash code for this object.
no setteroverride
hasUpdate → bool
Whether or not this object has been updated.
no setteroverride
hueNetwork ↔ HueNetwork?
The HueNetwork that this resource is associated with.
getter/setter pairinherited
id → String
Unique identifier representing a specific resource instance.
finalinherited
idV1 → String
Clip v1 resource identifier.
final
metadata ↔ RoomMetadata
Configuration object for this room.
getter/setter pair
originalType → ResourceType
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services → List<Relative>
References all services aggregating control and state of children in the group.
final
servicesAsResources → List<Resource>
Returns a list of the services as Resource objects.
no setter
type ↔ ResourceType
Type of the supported resource.
getter/setter pairinherited

Methods

copyWith({ResourceType? type, String? id, String? idV1, List<Relative>? children, List<Relative>? services, RoomMetadata? metadata, bool copyOriginalValues = true}) → Zone
Returns a copy of this object with its field values replaced by the ones provided to this method.
getRelativeAsResource(Relative relative) → Resource
Returns a Resource object that represents the relative of this Resource.
inherited
getRelativesAsResources(List<Relative> relatives) → List<Resource>
Returns a list of Resource objects that represent the relatives of this Resource.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshOriginals() → void
Called after a successful PUT request, this method refreshed the "original" data in this object.
override
toJson({OptimizeFor optimizeFor = OptimizeFor.put}) → Map<String, dynamic>
Converts this object into JSON format.
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override