HueHttpClient class

The Flutter Hue HTTP services.

It is advised that you use HueHttpRepo instead of this class.

Constructors

HueHttpClient()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

client → IOClient
The HTTP client that is used to talk to the Philips Hue bridge.
final

Static Methods

delete({required String url, required String applicationKey, required String? token}) → Future<Map<String, dynamic>?>
Delete an existing resource.
get({required String url, required String applicationKey, required String? token}) → Future<Map<String, dynamic>?>
Fetch an existing resource.
getHeaders({required String url, required String applicationKey, required String? token}) → Future<Map<String, String>?>
Fetch the headers of a resource call.
post({required String url, required String? applicationKey, required String? token, required String body}) → Future<Map<String, dynamic>?>
Create a new resource.
put({required String url, required String applicationKey, required String? token, required String body}) → Future<Map<String, dynamic>?>
Update an existing resource.