InvalidLongitudeException class

Exception thrown when an invalid longitude is encountered.

Inheritance

Constructors

InvalidLongitudeException([String? message])
Creates a InvalidLongitudeException object.
const
InvalidLongitudeException.withValue(double value, [String? message])
Creates a InvalidLongitudeException object that includes the value that triggered this exception.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
The error message associated with this exception.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double?
The number that caused this exception to be thrown.
finalinherited

Methods

getErrorMessage({required String exceptionType, required double? min, required double? max}) → String
Constructs the error message for this exception.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited