CorruptTokenDataException class

Exception thrown when the data in a stored token is corrupt.

Implemented types

Constructors

CorruptTokenDataException([String? message])
Creates a CorruptTokenDataException object.
const
CorruptTokenDataException.withValue(Map<String, dynamic>? value, [String? message])
Creates a CorruptTokenDataException object that includes the value that triggered this exception.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
The error message associated with this exception.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Map<String, dynamic>?
The number that caused this exception to be thrown.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited