ExpiredTokenException class abstract

Exception thrown when an expired token is encountered.

Implemented types
Implementers

Constructors

ExpiredTokenException([String? message])
Creates a ExpiredTokenException object.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
The error message associated with this exception.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getErrorMessage({required String exceptionType, required String hint}) → String
Constructs the error message for this exception.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited