MiscTools class

Miscellanies tools that are used throughout the app.

Constructors

MiscTools()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

extractData(Map<String, dynamic> dataMap) → Map<String, dynamic>
Used to extract the desired data from a raw JSON data map response.
extractDataList(Map<String, dynamic> dataMap) → List<Map<String, dynamic>>?
Used to extract the desired data from a raw JSON data map response.
randInt(int min, int max) → int
This method generates and returns a random integer from min to max (inclusive).